import 'dart:async';
import 'dart:convert';
import 'dart:io';
import '../consts.dart';
import 'marker_data.dart';

// fetchMarkerTemplate requests all marker data from the server
Future<List<Measurement>> fetchMarkerData() async {
  try {
    // Custom HTTP client
    HttpClient client = HttpClient()
      ..badCertificateCallback = // NB: temporary disable SSL certificate validation
          (X509Certificate cert, String host, int port) => true;

    // Request makers from API and wait for response
    var request = await client.getUrl(Uri.parse(serverURI + mapEndpoint));
    var response = await request.close();

    // Attempt to parse json if request is ok
    if (response.statusCode == 200) {
      var responseBody = await response.transform(utf8.decoder).join();

      List<dynamic> jsonData = json.decode(responseBody);

      return jsonData.map((data) => Measurement.Measurement(data)).toList();

    } else {
      print('Request failed with status: ${response.statusCode}');
      throw Exception('failed to parse marker data');
    }
  } catch (e) {
    print('Request failed with error ${e}');
    throw Exception('failed to connect to the server. Please check your network connection: ${e}');
  }
}
