from flask import request
import requests
import datetime
import json


# get_weather retrieves weather data for a list of coordinate pairs
def get_weather(self):
    # Extract coordinates form json data in POST request
    try:
        content_length = int(self.headers['Content-Length'])
        post_data = self.rfile.read(content_length)
        request_data = json.loads(post_data.decode('utf-8'))
        coordinates = request_data['coords']

    except KeyError:  # Coords key not found in request
        self.send_response(400)
        self.send_header("Content-type", "application/json")
        self.end_headers()
        response_message = {"error": "No 'coords' provided in request body"}
        self.wfile.write(json.dumps(response_message).encode('utf-8'))
        return

    except Exception as e:
        self.send_response(500)
        self.send_header("Content-type", "application/json")
        self.end_headers()
        response_message = {"error": "Failed to parse request body"}
        self.wfile.write(json.dumps(response_message).encode('utf-8'))
        return

    # Form timestamp string with correct format
    # Form timestamp string with correct format
    current_time = datetime.datetime.utcnow()
    current_time = current_time.replace(minute=0, second=0)
    current_time_str = current_time.strftime("%Y-%m-%dT%H:%M:%SZ")

    # Set User-Agent header
    user_agent = "IceApp sarasdj@stud.ntnu.no"
    headers = {'User-Agent': user_agent}

    # Empty list for weather data
    weather_data = []
    status_code = 500

    # Request weather data for each coordinate pair
    for coord in coordinates:
        lat = round(coord.get('lat'), 4)  # YR API only allows for up to 4 decimal points
        lng = round(coord.get('lng'), 4)

        # Construct request string and execute get request to Yr API
        url = f"https://api.met.no/weatherapi/locationforecast/2.0/compact?lat={lat}&lon={lng}"
        response = requests.get(url, headers=headers)

        if response.status_code == 200:
            if status_code != 200:
                status_code = 200

            data = response.json()  # Extract data from response
            timeseries = data['properties']['timeseries']

            # Get data for current time and append to weather_data
            for entry in timeseries:
                if entry['time'] == current_time_str:
                    data = entry['data']['instant']['details']
                    temperature = data['air_temperature']
                    humidity = data['relative_humidity']

                    weather_object = {
                        'Latitude': lat,
                        'Longitude': lng,
                        'Temperature': temperature,
                        'Humidity': humidity
                    }
                    # Append weather_object to weather_data list
                    weather_data.append(weather_object)
                    break


        else:  # Add error message if no weather data is found or the request fails
            print(f"Request to weather API failed with status code {response.status_code}") #NB: append error message to weather_data
            status_code = response.status_code

    # Set headers
    self.send_response(status_code)
    self.send_header("Content-type", "application/json")
    self.end_headers()

    # Write weather_data to response object
    self.wfile.write(json.dumps(weather_data).encode('utf-8'))
